//
//  ViewController.m
//  ChartTest
//
//  Created by Alan Lo on 26/10/2016.
//  Copyright © 2016 Alan Lo. All rights reserved.
//

@import Charts;

#import "ViewController.h"

@interface ViewController () <ChartViewDelegate>

@property (nonatomic, strong) IBOutlet BarChartView *barChartView;

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.barChartView.delegate = self;
    [self setupChart];
}

- (void)setupChart {
    
    self.barChartView.leftAxis.axisMaximum = 15000;
    self.barChartView.leftAxis.axisMinimum = 0;
    
    ChartLimitLine *limitLine = [[ChartLimitLine alloc] initWithLimit:self.barChartView.leftAxis.axisMaximum / 2.f];
    limitLine.lineWidth = 1.f;
    limitLine.lineColor = [UIColor lightGrayColor];
    [self.barChartView.leftAxis addLimitLine:limitLine];
    
    //self.barChar_stepsChart.leftAxis.enabled = FALSE;
    self.barChartView.rightAxis.enabled = FALSE;
    self.barChartView.legend.enabled = FALSE;
    self.barChartView.fitBars = TRUE;
    self.barChartView.chartDescription.enabled = FALSE;
    
    ChartXAxis *xAxis = self.barChartView.xAxis;
    xAxis.labelPosition = XAxisLabelPositionBottom;
    xAxis.labelFont = [UIFont systemFontOfSize:12.f];
    xAxis.drawGridLinesEnabled = NO;
    xAxis.granularity = 86400.0;
    
    [self setChartData];
}

- (void)setChartData {
    
    NSMutableArray *arr_tempEntry = [NSMutableArray array];
    for (int i = 0 ; i < 28 ; i++) {
        
        // comment out one of the following lines for xVal
        //double xVal = 86400.0 * (i + 1);
        double xVal = i + 1;
        NSInteger yVal = arc4random_uniform(15000);
        
        BarChartDataEntry *dataEntry = [[BarChartDataEntry alloc] initWithX:xVal y:yVal];
        [arr_tempEntry addObject:dataEntry];
        xVal++;
    }
    
    BarChartDataSet *dataSet = nil;
    if (self.barChartView.data.dataSetCount > 0) {
        dataSet = (BarChartDataSet *)[self.barChartView.data.dataSets firstObject];
        dataSet.values = arr_tempEntry;
        [self.barChartView.data notifyDataChanged];
        [self.barChartView notifyDataSetChanged];
    } else {
        dataSet = [[BarChartDataSet alloc] initWithValues:arr_tempEntry];
        [dataSet setColor:[UIColor colorWithRed:113/255.f green:200/255.f blue:177/255.f alpha:1.f]];
        //dataSet.drawValuesEnabled = FALSE;
        
        NSMutableArray *dataSets = [NSMutableArray array];
        [dataSets addObject:dataSet];
        
        BarChartData *data = [[BarChartData alloc] initWithDataSet:dataSet];
        data.barWidth = 0.8f;
        self.barChartView.data = data;
    }
}

@end
